@@ -8,7 +8,7 @@ from vellum_ee.workflows.display.workflows.get_vellum_workflow_display_class imp
 
 from tests.workflows.basic_api_node.workflow import SimpleAPIWorkflow
 
-# 0d76e1e1-3a4b-4eb4-a606-f73d62c -> 12e4a99d-883d-4da5-aa51-35817d94013e
+# 0d76e1e1-3a4b-4eb4-a606-f73d62c -> a0542dcc-443c-4b3b-aac8-c41d2277a5c7
 
 
 def test_serialize_workflow(vellum_client):
@@ -74,11 +74,11 @@ def test_serialize_workflow(vellum_client):
     api_node = workflow_raw_data["nodes"][1]
     assert not DeepDiff(
         {
-            "id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
+            "id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
             "type": "API",
             "inputs": [
                 {
-                    "id": "cd8a19f4-4eb7-4359-a8a6-918569c466a5",
+                    "id": "df921419-5ccb-4e1e-987f-b2349701b3db",
                     "key": "url",
                     "value": {
                         "rules": [
@@ -88,7 +88,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "fd61b5ac-39f9-4cfe-a839-f8ce78c202df",
+                    "id": "327b4d34-2803-4782-8449-fda65b12a064",
                     "key": "method",
                     "value": {
                         "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "STRING", "value": "POST"}}],
@@ -96,7 +96,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "c3a17ceb-e201-4025-b18a-9162aac7705e",
+                    "id": "470f5596-8fbd-4f34-af14-9b69b69dffcd",
                     "key": "body",
                     "value": {
                         "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "JSON", "value": {"key": "value"}}}],
@@ -104,7 +104,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "3092bf23-3202-4f3e-874c-9a33ccc73459",
+                    "id": "76fcf4b3-7e7f-4fc5-8065-18cb1c4c0225",
                     "key": "authorization_type",
                     "value": {
                         "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "STRING", "value": "API_KEY"}}],
@@ -112,7 +112,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "fee5e3c9-442a-4922-ba80-5ee07361cea7",
+                    "id": "94e73208-63db-4511-b86e-9fa285cdd1ad",
                     "key": "bearer_token_value",
                     "value": {
                         "rules": [
@@ -122,7 +122,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "2fcdfbc3-8095-4277-bb4a-a201fd326b54",
+                    "id": "1b3f6dfc-2053-4536-898a-747e64cc1313",
                     "key": "api_key_header_key",
                     "value": {
                         "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "STRING", "value": "CUSTOM_API_KEY"}}],
@@ -130,7 +130,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "d794bb51-a419-4fd8-be63-dfaf4166e831",
+                    "id": "7d728938-fd08-4224-81b4-5d5bc3d3bd57",
                     "key": "api_key_header_value",
                     "value": {
                         "rules": [
@@ -146,7 +146,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "57c31247-998a-430d-bb62-bf50eca7df35",
+                    "id": "416e4be7-f186-4ace-9619-637c54eeffb7",
                     "key": "additional_header_key",
                     "value": {
                         "rules": [{"type": "CONSTANT_VALUE", "data": {"type": "STRING", "value": "additional_header"}}],
@@ -154,7 +154,7 @@ def test_serialize_workflow(vellum_client):
                     },
                 },
                 {
-                    "id": "47b32274-f19b-4c15-b788-55c069c311c5",
+                    "id": "f2803619-eda1-4941-8d6a-288c87aca215",
                     "key": "additional_header_value",
                     "value": {
                         "rules": [
@@ -166,7 +166,7 @@ def test_serialize_workflow(vellum_client):
             ],
             "attributes": [
                 {
-                    "id": "ad719e65-0032-4012-a0bd-9b5162194bce",
+                    "id": "4377112c-8e3a-4636-adb4-8b0c0ddc71a9",
                     "name": "timeout",
                     "value": {
                         "type": "CONSTANT_VALUE",
@@ -177,24 +177,24 @@ def test_serialize_workflow(vellum_client):
             "data": {
                 "label": "Simple API Node",
                 "error_output_id": None,
-                "source_handle_id": "7c33b4d3-9204-4bd5-9371-80ee34f83073",
-                "target_handle_id": "14b538a5-aedb-41f3-b579-039956b7c7ed",
-                "url_input_id": "cd8a19f4-4eb7-4359-a8a6-918569c466a5",
-                "method_input_id": "fd61b5ac-39f9-4cfe-a839-f8ce78c202df",
-                "body_input_id": "c3a17ceb-e201-4025-b18a-9162aac7705e",
-                "authorization_type_input_id": "3092bf23-3202-4f3e-874c-9a33ccc73459",
-                "bearer_token_value_input_id": "fee5e3c9-442a-4922-ba80-5ee07361cea7",
-                "api_key_header_key_input_id": "2fcdfbc3-8095-4277-bb4a-a201fd326b54",
-                "api_key_header_value_input_id": "d794bb51-a419-4fd8-be63-dfaf4166e831",
+                "source_handle_id": "6c574f01-9362-4edd-b3dd-5faacca76b28",
+                "target_handle_id": "35816b8f-453b-4f70-a5fc-72dd0ceca460",
+                "url_input_id": "df921419-5ccb-4e1e-987f-b2349701b3db",
+                "method_input_id": "327b4d34-2803-4782-8449-fda65b12a064",
+                "body_input_id": "470f5596-8fbd-4f34-af14-9b69b69dffcd",
+                "authorization_type_input_id": "76fcf4b3-7e7f-4fc5-8065-18cb1c4c0225",
+                "bearer_token_value_input_id": "94e73208-63db-4511-b86e-9fa285cdd1ad",
+                "api_key_header_key_input_id": "1b3f6dfc-2053-4536-898a-747e64cc1313",
+                "api_key_header_value_input_id": "7d728938-fd08-4224-81b4-5d5bc3d3bd57",
                 "additional_headers": [
                     {
-                        "header_key_input_id": "57c31247-998a-430d-bb62-bf50eca7df35",
-                        "header_value_input_id": "47b32274-f19b-4c15-b788-55c069c311c5",
+                        "header_key_input_id": "416e4be7-f186-4ace-9619-637c54eeffb7",
+                        "header_value_input_id": "f2803619-eda1-4941-8d6a-288c87aca215",
                     }
                 ],
-                "text_output_id": "17342c21-12bb-49ab-88ce-f144e0376b32",
-                "json_output_id": "12e4a99d-883d-4da5-aa51-35817d94013e",
-                "status_code_output_id": "fecc16c3-400e-4fd3-8223-08366070e3b1",
+                "text_output_id": "f7190a6b-0c13-4a5a-9087-d8e6feb84eca",
+                "json_output_id": "a0542dcc-443c-4b3b-aac8-c41d2277a5c7",
+                "status_code_output_id": "f687c0a1-b63a-4c5c-b6ef-472c6108ae4b",
             },
             "display_data": {"position": {"x": 200.0, "y": -50.0}},
             "base": {
@@ -206,15 +206,15 @@ def test_serialize_workflow(vellum_client):
                 "module": ["tests", "workflows", "basic_api_node", "workflow"],
             },
             "trigger": {
-                "id": "14b538a5-aedb-41f3-b579-039956b7c7ed",
+                "id": "35816b8f-453b-4f70-a5fc-72dd0ceca460",
                 "merge_behavior": "AWAIT_ANY",
             },
-            "ports": [{"id": "7c33b4d3-9204-4bd5-9371-80ee34f83073", "name": "default", "type": "DEFAULT"}],
+            "ports": [{"id": "6c574f01-9362-4edd-b3dd-5faacca76b28", "name": "default", "type": "DEFAULT"}],
             "outputs": [
-                {"id": "12e4a99d-883d-4da5-aa51-35817d94013e", "name": "json", "type": "JSON", "value": None},
-                {"id": "0d76e1e1-3a4b-4eb4-a606-f73d62cf1a7e", "name": "headers", "type": "JSON", "value": None},
-                {"id": "fecc16c3-400e-4fd3-8223-08366070e3b1", "name": "status_code", "type": "NUMBER", "value": None},
-                {"id": "17342c21-12bb-49ab-88ce-f144e0376b32", "name": "text", "type": "STRING", "value": None},
+                {"id": "a0542dcc-443c-4b3b-aac8-c41d2277a5c7", "name": "json", "type": "JSON", "value": None},
+                {"id": "88082704-42bc-453f-a02a-40754453546b", "name": "headers", "type": "JSON", "value": None},
+                {"id": "f687c0a1-b63a-4c5c-b6ef-472c6108ae4b", "name": "status_code", "type": "NUMBER", "value": None},
+                {"id": "f7190a6b-0c13-4a5a-9087-d8e6feb84eca", "name": "text", "type": "STRING", "value": None},
             ],
         },
         api_node,
@@ -243,8 +243,8 @@ def test_serialize_workflow(vellum_client):
                                 {
                                     "type": "NODE_OUTPUT",
                                     "data": {
-                                        "node_id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
-                                        "output_id": "12e4a99d-883d-4da5-aa51-35817d94013e",
+                                        "node_id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
+                                        "output_id": "a0542dcc-443c-4b3b-aac8-c41d2277a5c7",
                                     },
                                 }
                             ],
@@ -279,8 +279,8 @@ def test_serialize_workflow(vellum_client):
                                 {
                                     "type": "NODE_OUTPUT",
                                     "data": {
-                                        "node_id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
-                                        "output_id": "0d76e1e1-3a4b-4eb4-a606-f73d62cf1a7e",
+                                        "node_id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
+                                        "output_id": "88082704-42bc-453f-a02a-40754453546b",
                                     },
                                 }
                             ],
@@ -315,8 +315,8 @@ def test_serialize_workflow(vellum_client):
                                 {
                                     "type": "NODE_OUTPUT",
                                     "data": {
-                                        "node_id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
-                                        "output_id": "fecc16c3-400e-4fd3-8223-08366070e3b1",
+                                        "node_id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
+                                        "output_id": "f687c0a1-b63a-4c5c-b6ef-472c6108ae4b",
                                     },
                                 }
                             ],
@@ -341,33 +341,33 @@ def test_serialize_workflow(vellum_client):
     assert not DeepDiff(
         [
             {
-                "id": "3c7551f5-0a76-4274-953e-c048b15f560a",
+                "id": "5e0e62cf-cdd9-4c47-ad19-ccbcdb41deac",
                 "source_node_id": "3a6b1467-5c83-4bcd-86a0-6415bc32d23b",
                 "source_handle_id": "8eaa7f02-25ff-4a00-9b0a-5185718d89b3",
-                "target_node_id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
-                "target_handle_id": "14b538a5-aedb-41f3-b579-039956b7c7ed",
+                "target_node_id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
+                "target_handle_id": "35816b8f-453b-4f70-a5fc-72dd0ceca460",
                 "type": "DEFAULT",
             },
             {
                 "id": "422bbbb7-38b2-4e19-ac95-24a86ed24100",
-                "source_node_id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
-                "source_handle_id": "7c33b4d3-9204-4bd5-9371-80ee34f83073",
+                "source_node_id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
+                "source_handle_id": "6c574f01-9362-4edd-b3dd-5faacca76b28",
                 "target_node_id": "8f975ab1-aca6-4dc1-aa80-c596f4e13afa",
                 "target_handle_id": "06853542-e1a1-4a00-bd1e-4ac40f347b32",
                 "type": "DEFAULT",
             },
             {
                 "id": "73007fe0-5cc2-435e-b2e4-6fa734153fbd",
-                "source_node_id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
-                "source_handle_id": "7c33b4d3-9204-4bd5-9371-80ee34f83073",
+                "source_node_id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
+                "source_handle_id": "6c574f01-9362-4edd-b3dd-5faacca76b28",
                 "target_node_id": "736f9bd0-f487-42af-bdb3-780b4941c61c",
                 "target_handle_id": "80d0894f-642e-4d2e-b43a-f236e7bedb3c",
                 "type": "DEFAULT",
             },
             {
                 "id": "4ac7d1c4-697b-440c-a35d-61ffb44a33b3",
-                "source_node_id": "facb80d7-ee08-42a0-82a9-ee26a9218185",
-                "source_handle_id": "7c33b4d3-9204-4bd5-9371-80ee34f83073",
+                "source_node_id": "6783c80f-5fc0-4712-a251-ce59d3c14ff2",
+                "source_handle_id": "6c574f01-9362-4edd-b3dd-5faacca76b28",
                 "target_node_id": "3f3ffc50-b156-48ac-b5f3-f68cb05c2b90",
                 "target_handle_id": "0c98c306-b519-40d7-8b05-321b1dfd7f11",
                 "type": "DEFAULT",
