@@ -83,11 +83,11 @@ def test_serialize_workflow():
     )
     assert not DeepDiff(
         {
-            "id": "5cf9c5e3-0eae-4daf-8d73-8b9536258eb9",
+            "id": "98597c0e-8951-4320-98ed-efd7f79c00cf",
             "type": "ERROR",
             "inputs": [
                 {
-                    "id": "8e4c8d76-2e02-4d7e-a7bf-d71af392dc49",
+                    "id": "f7fc097f-db5b-48c1-8c33-391834678521",
                     "key": "error_source_input_id",
                     "value": {
                         "rules": [
@@ -102,10 +102,10 @@ def test_serialize_workflow():
             ],
             "data": {
                 "label": "Fail Node",
-                "target_handle_id": "70c19f1c-309c-4a5d-ba65-664c0bb2fedf",
-                "error_source_input_id": "8e4c8d76-2e02-4d7e-a7bf-d71af392dc49",
+                "target_handle_id": "865dcf9c-8fe8-44c0-bf36-2c92eb47927e",
+                "error_source_input_id": "f7fc097f-db5b-48c1-8c33-391834678521",
             },
-            "display_data": {"position": {"x": 400.0, "y": 75.0}},
+            "display_data": {"position": {"x": 400.0, "y": -175.0}},
             "base": {
                 "name": "ErrorNode",
                 "module": ["vellum", "workflows", "nodes", "core", "error_node", "node"],
@@ -115,7 +115,7 @@ def test_serialize_workflow():
                 "module": ["tests", "workflows", "basic_error_node", "workflow"],
             },
             "trigger": {
-                "id": "70c19f1c-309c-4a5d-ba65-664c0bb2fedf",
+                "id": "865dcf9c-8fe8-44c0-bf36-2c92eb47927e",
                 "merge_behavior": "AWAIT_ATTRIBUTES",
             },
             "ports": [],
@@ -149,8 +149,8 @@ def test_serialize_workflow():
                             {
                                 "type": "NODE_OUTPUT",
                                 "data": {
-                                    "node_id": "1eee9b4e-531f-45f2-a4b9-42207fac2c33",
-                                    "output_id": "c6b017a4-25e9-4296-8d81-6aa4b3dad171",
+                                    "node_id": "f490ecde-1679-414b-8db5-2b706be25669",
+                                    "output_id": "29fbd4af-bb7f-40c3-a5c7-2bb47e12c534",
                                 },
                             }
                         ],
