@@ -15,6 +15,7 @@ from vellum.workflows.state.base import BaseState
 from vellum.workflows.triggers.base import _get_trigger_path_to_id_mapping
 from vellum.workflows.triggers.schedule import ScheduleTrigger
 from vellum.workflows.utils.uuids import uuid4_from_hash
+from vellum_ee.workflows.display.editor import NodeDisplayComment
 from vellum_ee.workflows.display.workflows.get_vellum_workflow_display_class import get_workflow_display
 
 
@@ -224,6 +225,7 @@ def test_scheduled_trigger_serialization_full():
             z_index = 3
             icon = "vellum:icon:calendar"
             color = "#4A90E2"
+            comment = NodeDisplayComment(value="This is scheduled trigger", expanded=True)
 
     class ProcessNode(BaseNode):
         class Outputs(BaseNode.Outputs):
@@ -250,16 +252,16 @@ def test_scheduled_trigger_serialization_full():
             "cron": "0 9 * * *",
             "timezone": "UTC",
             "attributes": [],
-            "display_data": {"icon": "vellum:icon:calendar", "color": "#4A90E2"},
-            "class_name": "DailyTriggerWithDisplay",
-            "module_path": [
-                "vellum_ee",
-                "workflows",
-                "display",
-                "tests",
-                "workflow_serialization",
-                "test_scheduled_trigger_serialization",
-            ],
-            "source_handle_id": "f3e5eddb-75da-42e6-9abf-d616f30c145c",
+            "display_data": {
+                "label": "Daily Schedule",
+                "position": {"x": 100.5, "y": 200.75},
+                "z_index": 3,
+                "icon": "vellum:icon:calendar",
+                "color": "#4A90E2",
+                "comment": {
+                    "value": "This is scheduled trigger",
+                    "expanded": True,
+                },
+            },
         },
     )
