@@ -1,7 +1,5 @@
 from dataclasses import asdict, is_dataclass
 import inspect
-from io import StringIO
-import sys
 from uuid import UUID
 from typing import TYPE_CHECKING, Any, Dict, List, Optional, cast
 
@@ -56,31 +54,15 @@ from vellum.workflows.references.vellum_secret import VellumSecretReference
 from vellum.workflows.references.workflow_input import WorkflowInputReference
 from vellum.workflows.types.core import JsonArray, JsonObject
 from vellum.workflows.types.generics import is_workflow_class
+from vellum.workflows.utils.files import virtual_open
 from vellum.workflows.utils.functions import compile_function_definition
 from vellum.workflows.utils.uuids import uuid4_from_hash
 from vellum_ee.workflows.display.utils.exceptions import InvalidInputReferenceError, UnsupportedSerializationException
-from vellum_ee.workflows.server.virtual_file_loader import VirtualFileLoader
 
 if TYPE_CHECKING:
     from vellum_ee.workflows.display.types import WorkflowDisplayContext
 
 
-def virtual_open(file_path: str, mode: str = "r"):
-    """
-    Open a file, checking VirtualFileFinder instances first before falling back to regular open().
-    """
-    for finder in sys.meta_path:
-        if hasattr(finder, "loader") and isinstance(finder.loader, VirtualFileLoader):
-            namespace = finder.loader.namespace
-            if file_path.startswith(namespace + "/"):
-                relative_path = file_path[len(namespace) + 1 :]
-                content = finder.loader._get_code(relative_path)
-                if content is not None:
-                    return StringIO(content)
-
-    return open(file_path, mode)
-
-
 def convert_descriptor_to_operator(descriptor: BaseDescriptor) -> LogicalOperator:
     if isinstance(descriptor, EqualsExpression):
         return "="
