@@ -14,6 +14,7 @@ from vellum.client.types.prompt_parameters import PromptParameters
 from vellum.client.types.prompt_settings import PromptSettings
 from vellum.client.types.string_chat_message_content import StringChatMessageContent
 from vellum.client.types.variable_prompt_block import VariablePromptBlock
+from vellum.utils.json_encoder import VellumJsonEncoder
 from vellum.workflows.descriptors.base import BaseDescriptor
 from vellum.workflows.errors.types import WorkflowErrorCode
 from vellum.workflows.exceptions import NodeException
@@ -30,7 +31,6 @@ from vellum.workflows.nodes.displayable.tool_calling_node.state import ToolCalli
 from vellum.workflows.outputs.base import BaseOutput
 from vellum.workflows.ports.port import Port
 from vellum.workflows.state import BaseState
-from vellum.workflows.state.encoder import DefaultStateEncoder
 from vellum.workflows.types.core import EntityInputsInterface, MergeBehavior
 from vellum.workflows.types.definition import (
     ComposioToolDefinition,
@@ -101,7 +101,7 @@ class FunctionCallNodeMixin:
         state.chat_history.append(
             ChatMessage(
                 role="FUNCTION",
-                content=StringChatMessageContent(value=json.dumps(result, cls=DefaultStateEncoder)),
+                content=StringChatMessageContent(value=json.dumps(result, cls=VellumJsonEncoder)),
                 source=function_call_id,
             )
         )
@@ -421,46 +421,35 @@ def create_router_node(
         # Create dynamic ports and convert functions in a single loop
         Ports = type("Ports", (), {})
 
-        # Avoid using lambda to capture function_name
-        # lambda will capture the function_name by reference,
-        # and if the function_name is changed, the port_condition will also change.
-        def create_port_condition(fn_name, is_first):
-            condition = (
+        # Collect all tool names
+        tool_names: List[str] = []
+        for function in functions:
+            if isinstance(function, MCPServer):
+                tool_functions: List[MCPToolDefinition] = compile_mcp_tool_definition(function)
+                for tool_function in tool_functions:
+                    tool_names.append(get_mcp_tool_name(tool_function))
+            else:
+                tool_names.append(get_function_name(function))
+
+        # Build conditions for each tool name
+        conditions = [
+            (
+                name,
                 ToolCallingState.current_prompt_output_index.less_than(tool_prompt_node.Outputs.results.length())
                 & tool_prompt_node.Outputs.results[ToolCallingState.current_prompt_output_index]["type"].equals(
                     "FUNCTION_CALL"
                 )
                 & tool_prompt_node.Outputs.results[ToolCallingState.current_prompt_output_index]["value"][
                     "name"
-                ].equals(fn_name)
+                ].equals(name),
             )
-            # First port should be on_if, subsequent ports should be on_elif
-            return Port.on_if(condition) if is_first else Port.on_elif(condition)
+            for name in tool_names
+        ]
 
-        is_first_port = True
-        for function in functions:
-            if isinstance(function, ComposioToolDefinition):
-                function_name = get_function_name(function)
-                port = create_port_condition(function_name, is_first_port)
-                setattr(Ports, function_name, port)
-                is_first_port = False
-            elif isinstance(function, VellumIntegrationToolDefinition):
-                function_name = get_function_name(function)
-                port = create_port_condition(function_name, is_first_port)
-                setattr(Ports, function_name, port)
-                is_first_port = False
-            elif isinstance(function, MCPServer):
-                tool_functions: List[MCPToolDefinition] = compile_mcp_tool_definition(function)
-                for tool_function in tool_functions:
-                    name = get_mcp_tool_name(tool_function)
-                    port = create_port_condition(name, is_first_port)
-                    setattr(Ports, name, port)
-                    is_first_port = False
-            else:
-                function_name = get_function_name(function)
-                port = create_port_condition(function_name, is_first_port)
-                setattr(Ports, function_name, port)
-                is_first_port = False
+        # Assign ports: first condition uses on_if, subsequent ones use on_elif
+        for idx, (name, condition) in enumerate(conditions):
+            port = Port.on_if(condition) if idx == 0 else Port.on_elif(condition)
+            setattr(Ports, name, port)
 
         # Add the else port for when no function conditions match
         setattr(Ports, "default", Port.on_else())
