@@ -262,6 +262,7 @@ class WorkflowRunner(Generic[StateType]):
         self._cancel_signal = cancel_signal
         self._timeout = timeout
         self._execution_context = init_execution_context or get_execution_context()
+        self._trigger = trigger
 
         setattr(
             self._initial_state,
@@ -385,20 +386,6 @@ class WorkflowRunner(Generic[StateType]):
                 if issubclass(trigger_type, IntegrationTrigger):
                     workflow_integration_triggers.append(trigger_type)
 
-        if workflow_integration_triggers:
-            if not self._has_manual_trigger():
-                # Workflow has ONLY IntegrationTrigger - this is an error
-                raise WorkflowInitializationException(
-                    message="Workflow has IntegrationTrigger which requires trigger parameter",
-                    workflow_definition=self.workflow.__class__,
-                    code=WorkflowErrorCode.INVALID_INPUTS,
-                )
-
-            # Workflow has both IntegrationTrigger and ManualTrigger - filter to ManualTrigger path
-            manual_entrypoints = self._get_entrypoints_for_trigger_type(ManualTrigger)
-            if manual_entrypoints:
-                self._entrypoints = manual_entrypoints
-
     @contextmanager
     def _httpx_logger_with_span_id(self) -> Iterator[None]:
         """
@@ -949,6 +936,7 @@ class WorkflowRunner(Generic[StateType]):
                 workflow_definition=self.workflow.__class__,
                 inputs=self._initial_state.meta.workflow_inputs,
                 initial_state=deepcopy(self._initial_state) if self._should_emit_initial_state else None,
+                trigger=self._trigger.__class__ if self._trigger else None,
             ),
             parent=self._execution_context.parent_context,
             links=links,
