@@ -1,4 +1,5 @@
 import pytest
+from datetime import datetime
 from typing import List
 
 from vellum.workflows.inputs.base import BaseInputs
@@ -6,6 +7,7 @@ from vellum.workflows.inputs.dataset_row import DatasetRow
 from vellum.workflows.nodes.bases.base import BaseNode
 from vellum.workflows.sandbox import WorkflowSandboxRunner
 from vellum.workflows.state.base import BaseState
+from vellum.workflows.triggers import ScheduleTrigger
 from vellum.workflows.workflows.base import BaseWorkflow
 
 
@@ -100,3 +102,53 @@ def test_sandbox_runner_with_dict_inputs(mock_logger):
         "----------------------------------",
         "final_output: Hello from dict",
     ]
+
+
+def test_sandbox_runner_with_workflow_trigger(mock_logger):
+    """
+    Test that WorkflowSandboxRunner can run with DatasetRow containing workflow_trigger.
+    """
+
+    # GIVEN we capture the logs to stdout
+    logs = []
+    mock_logger.return_value.info.side_effect = lambda msg: logs.append(msg)
+
+    class MySchedule(ScheduleTrigger):
+        class Config(ScheduleTrigger.Config):
+            cron = "* * * * *"
+            timezone = "UTC"
+
+    class StartNode(BaseNode):
+        class Outputs(BaseNode.Outputs):
+            result = MySchedule.current_run_at
+
+    class Workflow(BaseWorkflow):
+        graph = MySchedule >> StartNode
+
+        class Outputs(BaseWorkflow.Outputs):
+            final_output = StartNode.Outputs.result
+
+    # AND a dataset with workflow_trigger
+    dataset = [
+        DatasetRow(
+            label="test_row",
+            inputs={"current_run_at": datetime.min, "next_run_at": datetime.now()},
+            workflow_trigger=MySchedule,
+        ),
+    ]
+
+    # WHEN we run the sandbox with the DatasetRow containing workflow_trigger
+    runner = WorkflowSandboxRunner(workflow=Workflow(), dataset=dataset)
+    runner.run()
+
+    # THEN the workflow should run successfully
+    assert logs == [
+        "Just started Node: StartNode",
+        "Just finished Node: StartNode",
+        "Workflow fulfilled!",
+        "----------------------------------",
+        "final_output: 0001-01-01 00:00:00",
+    ]
+
+    # AND the dataset row should still have the trigger class
+    assert dataset[0].workflow_trigger == MySchedule
